---
name: Feature request
about: Want to see something added or improved? Tell me all about it.
title: ''
labels: feature
assignees: marzer

---

<!--
    Replace the HTML comments below with the requested information.
    Please don't delete this template and roll your own!

    Thanks for contributing!
-->



**Is your feature request related to a problem? Please describe.**
<!--
    "I'd like a way to Fooify all Bars in one go. Currently I have to iterate through them and
    do it individually myself, which is cumbersome.
-->



**Describe the solution you'd like**
<!--
    A helper function like fooify_all_bars() would be great.
-->




**Additional context**
<!--
    Add any other context or screenshots about the feature request here.
-->
